from astropy.units import *
import astropy.constants as constants

def_unit(['f_u_', 'Formula_Unit'], dimensionless_unscaled, namespace=globals())
def_unit('mu_B', constants.muB, namespace=globals())
